EztoVerifyApp class
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatefulWidget
- EztoVerifyApp
Constructors
-
EztoVerifyApp({Key? key, required Widget child, required void onResult(String reqId, String authReqId)?, Future<
bool> onPermissionDenied(List<SystemPermission> deniedPermissions)?, Future<GetTokenModel> onPushTokenRequest()?, void onTransactionRequest(Map<String, dynamic> data, bool isFromDeeplink)?, Future<String> onSocketPushUrlRequest()?, void onClose(CloseReason reason)?, void onError(ErrorCode reason)?, void onFileDownloadEnd(String path, String mimeType, String fileName)?, void onFileDownloadStart(String fileName, String mimeType)?, ForceUpdate forceUpdate = const ForceUpdate(), bool closeImmediatelyOnResult = false, ThemeData? theme})
Properties
- child → Widget
-
final
- closeImmediatelyOnResult → bool
-
final
- forceUpdate → ForceUpdate
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- onClose → void Function(CloseReason reason)?
-
final
- onError → void Function(ErrorCode reason)?
-
final
- onFileDownloadEnd → void Function(String path, String mimeType, String fileName)?
-
final
- onFileDownloadStart → void Function(String fileName, String mimeType)?
-
final
-
onPermissionDenied
→ Future<
bool> Function(List<SystemPermission> deniedPermissions)? -
final
-
onPushTokenRequest
→ Future<
GetTokenModel> Function()? -
final
- onResult → void Function(String reqId, String authReqId)?
-
final
-
onSocketPushUrlRequest
→ Future<
String> Function() -
final
-
onTransactionRequest
→ void Function(Map<
String, dynamic> data, bool isFromDeeplink)? -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- theme → ThemeData
-
final
Methods
-
createElement(
) → StatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → State< EztoVerifyApp> -
Creates the mutable state for this widget at a given location in the tree.
override
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited