SystemServiceHandler class

Inheritance

Constructors

SystemServiceHandler()

Properties

hashCode → int
The hash code for this object.
no setterinherited
requiredPermissions → List<Permission>
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

checkForPermissions() → Future<List<Status>>
inherited
copyToClipboard(List args) → Future<Map<String, dynamic>>
getCurrentNetwork(List args) → Future<Map<String, dynamic>>
getDeviceInfo() → Future<Map<String, dynamic>>
inherited
isCustomSchemeRegisteredOnApp(List args) → Future<Map<String, dynamic>>
loadSekuraSessionUrl(List args) → Future<Map<String, dynamic>>
mapErrors(String? errorCode) → List<String>
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
processArgs(List args) → Map<String, dynamic>
inherited
toString() → String
A string representation of this object.
inherited
validateRequiredFields(Map<String, dynamic> args, List<String> fieldKeys) → List<String>
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited