DbEncryptEncoder class

Inheritance

Constructors

DbEncryptEncoder({required String password})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
password → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

bind(Stream<Map<String, dynamic>> stream) → Stream<String>
Transforms the provided stream.
inherited
cast<RS, RT>() → Converter<RS, RT>
Provides a Converter<RS, RT> view of this stream transformer.
inherited
convert(Map<String, dynamic> input) → String
Converts input and returns the result of the conversion.
override
fuse<TT>(Converter<String, TT> other) → Converter<Map<String, dynamic>, TT>
Fuses this with other.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
startChunkedConversion(Sink<String> sink) → Sink<Map<String, dynamic>>
Starts a chunked conversion.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited