FieldErrorModel class

Constructors

FieldErrorModel({bool success = false, String message = "Required fields missing", List<Status> errorCodes = const [Status.jsMissingFields], required Map<String, dynamic> device})
FieldErrorModel.fromJson(String source)
factory
FieldErrorModel.fromMap(Map<String, dynamic> map)
factory

Properties

device → Map<String, dynamic>
final
errorCodes → List<Status>
final
hashCode → int
The hash code for this object.
no setterinherited
message → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
success → bool
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → String
toMap() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited