ForceUpdate class

Constructors

ForceUpdate({UpgradeConfig android = const UpgradeConfig(shouldForceUpdate: false), UpgradeConfig ios = const UpgradeConfig(shouldForceUpdate: false), UpgradeConfig mac = const UpgradeConfig(shouldForceUpdate: false), UpgradeConfig windows = const UpgradeConfig(shouldForceUpdate: false)})
const

Properties

android → UpgradeConfig
final
hashCode → int
The hash code for this object.
no setterinherited
ios → UpgradeConfig
final
mac → UpgradeConfig
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
windows → UpgradeConfig
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited