Data class

Constructors

Data({required String action, required String type, required Socket socket})
Data.fromEncrypted({required String encrypted, String? encryptionKey})
factory
Data.fromJson(String source)
factory
Data.fromMap(Map<String, dynamic> map)
factory

Properties

action → String
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
socket → Socket
final
type → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → String
toMap() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited