Payload class

Constructors

Payload({required int version, required String id, required bool isEncrypted, required Data data})
Payload.fromMap({required Map<String, dynamic> map, String? encryptionKey})
factory

Properties

data → Data
final
hashCode → int
The hash code for this object.
no setterinherited
id → String
final
isEncrypted → bool
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
version → int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → String
toMap() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited