addMenuItem method

void addMenuItem(
  1. InAppBrowserMenuItem menuItem
)
inherited

Adds a InAppBrowserMenuItem to the menu. If the browser is already open, it will take effect the next time it is opened.

Officially Supported Platforms/Implementations:

  • Android WebView
  • iOS WKWebView 14.0+
  • macOS WKWebView 10.15+

Parameters - Officially Supported Platforms/Implementations:

  • menuItem: all platforms

Use the PlatformInAppBrowser.isMethodSupported method to check if this method is supported at runtime.

Implementation

void addMenuItem(InAppBrowserMenuItem menuItem) =>
    platform.addMenuItem(menuItem);