onCloseWindow method
Event fired when the host application should close the given WebView and remove it from the view system if necessary. At this point, WebCore has stopped any loading in this window and has removed any cross-scripting ability in javascript.
Officially Supported Platforms/Implementations:
- Android WebView (Official API - WebChromeClient.onCloseWindow)
- iOS WKWebView (Official API - WKUIDelegate.webViewDidClose)
- macOS WKWebView (Official API - WKUIDelegate.webViewDidClose)
- Web <iframe> but requires same origin
- Windows WebView2 (Official API - ICoreWebView2.add_WindowCloseRequested)
Use the PlatformInAppBrowserEvents.isMethodSupported method to check if this method is supported at runtime.
Implementation
@override
void onCloseWindow() {}