onContentSizeChanged method

  1. @override
void onContentSizeChanged(
  1. Size oldContentSize,
  2. Size newContentSize
)
inherited

Event fired when the content size of the WebView changes.

oldContentSize represents the old content size value.

newContentSize represents the new content size value.

Officially Supported Platforms/Implementations:

  • iOS WKWebView

Parameters - Officially Supported Platforms/Implementations:

  • oldContentSize: all platforms
  • newContentSize: all platforms

Use the PlatformInAppBrowserEvents.isMethodSupported method to check if this method is supported at runtime.

Implementation

@override
void onContentSizeChanged(Size oldContentSize, Size newContentSize) {}