onEnterFullscreen method

  1. @override
void onEnterFullscreen()
inherited

Event fired when the current page has entered full screen mode.

Officially Supported Platforms/Implementations:

Use the PlatformInAppBrowserEvents.isMethodSupported method to check if this method is supported at runtime.

Implementation

@override
void onEnterFullscreen() {}