onFormResubmission method

  1. @override
FutureOr<FormResubmissionAction?>? onFormResubmission(
  1. WebUri? url
)
inherited

As the host application if the browser should resend data as the requested page was a result of a POST. The default is to not resend the data.

Officially Supported Platforms/Implementations:

Parameters - Officially Supported Platforms/Implementations:

  • url: all platforms

Use the PlatformInAppBrowserEvents.isMethodSupported method to check if this method is supported at runtime.

Implementation

@override
FutureOr<FormResubmissionAction?>? onFormResubmission(WebUri? url) {
  return null;
}