onJsPrompt method

  1. @override
FutureOr<JsPromptResponse?>? onJsPrompt(
  1. JsPromptRequest jsPromptRequest
)
inherited

Event fired when javascript calls the prompt() method to display a prompt dialog. If JsPromptResponse.handledByClient is true, the webview will assume that the client will handle the dialog.

jsPromptRequest contains the message to be displayed in the prompt dialog, the default value displayed in the prompt dialog, and the of the page requesting the dialog.

Officially Supported Platforms/Implementations:

Parameters - Officially Supported Platforms/Implementations:

  • jsPromptRequest: all platforms

Use the PlatformInAppBrowserEvents.isMethodSupported method to check if this method is supported at runtime.

Implementation

@override
FutureOr<JsPromptResponse?>? onJsPrompt(JsPromptRequest jsPromptRequest) {
  return null;
}