onMainWindowWillClose method

  1. @override
void onMainWindowWillClose()
inherited

Event fired when the main window is about to close.

Officially Supported Platforms/Implementations:

  • macOS WKWebView

Use the PlatformInAppBrowserEvents.isMethodSupported method to check if this method is supported at runtime.

Implementation

@override
void onMainWindowWillClose() {}