onOverScrolled method
Event fired to respond to the results of an over-scroll operation.
x represents the new X scroll value in pixels.
y represents the new Y scroll value in pixels.
clampedX is true if x was clamped to an over-scroll boundary.
clampedY is true if y was clamped to an over-scroll boundary.
Officially Supported Platforms/Implementations:
- Android WebView (Official API - WebView.onOverScrolled)
- iOS WKWebView
Parameters - Officially Supported Platforms/Implementations:
x: all platformsy: all platformsclampedX: all platformsclampedY: all platforms
Use the PlatformInAppBrowserEvents.isMethodSupported method to check if this method is supported at runtime.
Implementation
@override
void onOverScrolled(int x, int y, bool clampedX, bool clampedY) {}