onPageCommitVisible method
Called when the web view begins to receive web content.
This event occurs early in the document loading process, and as such you should expect that linked resources (for example, CSS and images) may not be available.
url represents the URL corresponding to the page navigation that triggered this callback.
Officially Supported Platforms/Implementations:
- Android WebView (Official API - WebViewClient.onPageCommitVisible)
- iOS WKWebView (Official API - WKNavigationDelegate.webView)
- macOS WKWebView (Official API - WKNavigationDelegate.webView)
Parameters - Officially Supported Platforms/Implementations:
url: all platforms
Use the PlatformInAppBrowserEvents.isMethodSupported method to check if this method is supported at runtime.
Implementation
@override
void onPageCommitVisible(WebUri? url) {}