onProcessFailed method

  1. @override
void onProcessFailed(
  1. ProcessFailedDetail detail
)
inherited

Invoked when any of the processes in the WebView Process Group encounters one of the following conditions:

  • Unexpected exit: The process indicated by the event args has exited unexpectedly (usually due to a crash). The failure might or might not be recoverable and some failures are auto-recoverable.
  • Unresponsiveness: The process indicated by the event args has become unresponsive to user input. This is only reported for renderer processes, and will run every few seconds until the process becomes responsive again.

Officially Supported Platforms/Implementations:

Parameters - Officially Supported Platforms/Implementations:

  • detail: all platforms

Use the PlatformInAppBrowserEvents.isMethodSupported method to check if this method is supported at runtime.

Implementation

@override
void onProcessFailed(ProcessFailedDetail detail) {}