onProgressChanged method

  1. @override
void onProgressChanged(
  1. int progress
)

Event fired when the current progress of loading a page is changed.

Officially Supported Platforms/Implementations:

Parameters - Officially Supported Platforms/Implementations:

  • progress: all platforms

Use the PlatformInAppBrowserEvents.isMethodSupported method to check if this method is supported at runtime.

Implementation

@override
void onProgressChanged(progress) {
  if (progress == 100) {
    pullToRefreshController?.endRefreshing();
  }
}