onReceivedClientCertRequest method
FutureOr<ClientCertResponse?> ?
onReceivedClientCertRequest(
- ClientCertChallenge challenge
inherited
Notify the host application to handle an SSL client certificate request.
Webview stores the response in memory (for the life of the application) if ClientCertResponseAction.PROCEED or ClientCertResponseAction.CANCEL
is called and does not call onReceivedClientCertRequest again for the same host and port pair.
Note that, multiple layers in chromium network stack might be caching the responses.
challenge contains data about host, port, protocol, realm, etc. as specified in the ClientCertChallenge.
Officially Supported Platforms/Implementations:
- Android WebView (Official API - WebViewClient.onReceivedClientCertRequest)
- iOS WKWebView (Official API - WKNavigationDelegate.webView)
- macOS WKWebView (Official API - WKNavigationDelegate.webView)
- Windows WebView2 (Official API - ICoreWebView2_5.add_ClientCertificateRequested)
Parameters - Officially Supported Platforms/Implementations:
challenge: all platforms
Use the PlatformInAppBrowserEvents.isMethodSupported method to check if this method is supported at runtime.
Implementation
@override
FutureOr<ClientCertResponse?>? onReceivedClientCertRequest(
ClientCertChallenge challenge,
) {
return null;
}