onReceivedLoginRequest method

  1. @override
void onReceivedLoginRequest(
  1. LoginRequest loginRequest
)
inherited

Event fired when a request to automatically log in the user has been processed.

loginRequest contains the realm, account and args of the login request.

Officially Supported Platforms/Implementations:

Parameters - Officially Supported Platforms/Implementations:

  • loginRequest: all platforms

Use the PlatformInAppBrowserEvents.isMethodSupported method to check if this method is supported at runtime.

Implementation

@override
void onReceivedLoginRequest(LoginRequest loginRequest) {}