onReceivedServerTrustAuthRequest method

  1. @override
FutureOr<ServerTrustAuthResponse?>? onReceivedServerTrustAuthRequest(
  1. ServerTrustChallenge challenge
)
inherited

Event fired when the WebView need to perform server trust authentication (certificate validation). The host application must return either ServerTrustAuthResponse instance with ServerTrustAuthResponseAction.CANCEL or ServerTrustAuthResponseAction.PROCEED.

challenge contains data about host, port, protocol, realm, etc. as specified in the ServerTrustChallenge.

Officially Supported Platforms/Implementations:

Parameters - Officially Supported Platforms/Implementations:

  • challenge: all platforms

Use the PlatformInAppBrowserEvents.isMethodSupported method to check if this method is supported at runtime.

Implementation

@override
FutureOr<ServerTrustAuthResponse?>? onReceivedServerTrustAuthRequest(
  ServerTrustChallenge challenge,
) {
  return null;
}