onRenderProcessGone method
Event fired when the given WebView's render process has exited. The application's implementation of this callback should only attempt to clean up the WebView. The WebView should be removed from the view hierarchy, all references to it should be cleaned up.
To cause an render process crash for test purpose, the application can call load url "chrome://crash" on the WebView.
Note that multiple WebView instances may be affected if they share a render process, not just the specific WebView which loaded "chrome://crash".
detail the reason why it exited.
Officially Supported Platforms/Implementations:
- Android WebView 26+ (Official API - WebViewClient.onRenderProcessGone)
- Windows WebView2 (Official API - ICoreWebView2.add_ProcessFailed)
Parameters - Officially Supported Platforms/Implementations:
detail: all platforms
Use the PlatformInAppBrowserEvents.isMethodSupported method to check if this method is supported at runtime.
Implementation
@override
void onRenderProcessGone(RenderProcessGoneDetail detail) {}