onRenderProcessResponsive method

  1. @override
FutureOr<WebViewRenderProcessAction?>? onRenderProcessResponsive(
  1. WebUri? url
)
inherited

Event called once when an unresponsive renderer currently associated with the WebView becomes responsive.

After a WebView renderer becomes unresponsive, which is notified to the application by onRenderProcessUnresponsive, it is possible for the blocking renderer task to complete, returning the renderer to a responsive state. In that case, this method is called once to indicate responsiveness.

No action is taken by WebView as a result of this method call.

Officially Supported Platforms/Implementations:

Parameters - Officially Supported Platforms/Implementations:

  • url: all platforms

Use the PlatformInAppBrowserEvents.isMethodSupported method to check if this method is supported at runtime.

Implementation

@override
FutureOr<WebViewRenderProcessAction?>? onRenderProcessResponsive(
  WebUri? url,
) {
  return null;
}