onScrollChanged method

  1. @override
void onScrollChanged(
  1. int x,
  2. int y
)
inherited

Event fired when the WebView scrolls.

x represents the current horizontal scroll origin in pixels.

y represents the current vertical scroll origin in pixels.

Officially Supported Platforms/Implementations:

Parameters - Officially Supported Platforms/Implementations:

  • x: all platforms
  • y: all platforms

Use the PlatformInAppBrowserEvents.isMethodSupported method to check if this method is supported at runtime.

Implementation

@override
void onScrollChanged(int x, int y) {}