onWebContentProcessDidTerminate method
Invoked when the web view's web content process is terminated. Reloading the page will start a new render process if needed.
Officially Supported Platforms/Implementations:
- iOS WKWebView (Official API - WKNavigationDelegate.webViewWebContentProcessDidTerminate)
- macOS WKWebView (Official API - WKNavigationDelegate.webViewWebContentProcessDidTerminate)
- Windows WebView2 (Official API - ICoreWebView2.add_ProcessFailed)
Use the PlatformInAppBrowserEvents.isMethodSupported method to check if this method is supported at runtime.
Implementation
@override
void onWebContentProcessDidTerminate() {}