onZoomScaleChanged method

  1. @override
void onZoomScaleChanged(
  1. double oldScale,
  2. double newScale
)
inherited

Event fired when the zoom scale of the WebView has changed.

oldScale The old zoom scale factor.

newScale The new zoom scale factor.

Officially Supported Platforms/Implementations:

Parameters - Officially Supported Platforms/Implementations:

  • oldScale: all platforms
  • newScale: all platforms

Use the PlatformInAppBrowserEvents.isMethodSupported method to check if this method is supported at runtime.

Implementation

@override
void onZoomScaleChanged(double oldScale, double newScale) {}