removeAllMenuItem method
void
removeAllMenuItem()
inherited
Removes all the menu items from the list. If the browser is already open, it will take effect the next time it is opened.
Officially Supported Platforms/Implementations:
- Android WebView
- iOS WKWebView 14.0+
- macOS WKWebView 10.15+
Use the PlatformInAppBrowser.isMethodSupported method to check if this method is supported at runtime.
Implementation
void removeAllMenuItem() => platform.removeAllMenuItem();