removeMenuItem method

bool removeMenuItem(
  1. InAppBrowserMenuItem menuItem
)
inherited

Removes the menuItem from the list. Returns true if it was in the list, false otherwise. If the browser is already open, it will take effect the next time it is opened.

Officially Supported Platforms/Implementations:

  • Android WebView
  • iOS WKWebView 14.0+
  • macOS WKWebView 10.15+

Parameters - Officially Supported Platforms/Implementations:

  • menuItem: all platforms

Use the PlatformInAppBrowser.isMethodSupported method to check if this method is supported at runtime.

Implementation

bool removeMenuItem(InAppBrowserMenuItem menuItem) =>
    platform.removeMenuItem(menuItem);