removeMenuItems method

void removeMenuItems(
  1. List<InAppBrowserMenuItem> menuItems
)
inherited

Removes a list of menuItems from the list. If the browser is already open, it will take effect the next time it is opened.

Officially Supported Platforms/Implementations:

  • Android WebView
  • iOS WKWebView 14.0+
  • macOS WKWebView 10.15+

Parameters - Officially Supported Platforms/Implementations:

  • menuItems: all platforms

Use the PlatformInAppBrowser.isMethodSupported method to check if this method is supported at runtime.

Implementation

void removeMenuItems(List<InAppBrowserMenuItem> menuItems) =>
    platform.removeMenuItems(menuItems);