shouldAllowDeprecatedTLS method

  1. @override
FutureOr<ShouldAllowDeprecatedTLSAction?>? shouldAllowDeprecatedTLS(
  1. URLAuthenticationChallenge challenge
)
inherited

Called when a web view asks whether to continue with a connection that uses a deprecated version of TLS (v1.0 and v1.1).

challenge represents the authentication challenge.

Officially Supported Platforms/Implementations:

Parameters - Officially Supported Platforms/Implementations:

  • challenge: all platforms

Use the PlatformInAppBrowserEvents.isMethodSupported method to check if this method is supported at runtime.

Implementation

@override
FutureOr<ShouldAllowDeprecatedTLSAction?>? shouldAllowDeprecatedTLS(
  URLAuthenticationChallenge challenge,
) {
  return null;
}