EncryptionService class

Constructors

EncryptionService()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

aesCbcDecrypt(Uint8List key, Uint8List cipherText) → Uint8List
aesCbcEncrypt(Uint8List key, Uint8List paddedPlaintext) → Uint8List
decryptPushWithAes(String key, String encrytedData) → String
encryptWithRsa(String publicKey, String challenge) → String
generateDbKey() → Future<Uint8List>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toSha256Hash(Uint8List dataToDigest) → String
toSha512(Uint8List dataToDigest) → String
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited