JavaScriptHandlerService class

Constructors

JavaScriptHandlerService({required Socket socketInfo, MacWebViewBrowser? inAppBrowser, required BuildContext context})

Properties

context → BuildContext
final
hashCode → int
The hash code for this object.
no setterinherited
inAppBrowser → MacWebViewBrowser?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
socketInfo → Socket
final

Methods

dispose() → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
register(PlatformWebViewController controller, {required Socket socketInfo}) → Future<void>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited