StorageService class

Constructors

StorageService()

Properties

db ↔ Database
getter/setter pair
dbFactory ↔ DatabaseFactory
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

createOrGetDeviceId() → Future<String>
init() → Future<void>
isFirstRun() → Future<bool>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
readBioPublicKey() → Future<PublicKeyModel?>
toString() → String
A string representation of this object.
inherited
writeBioPublicKey(String publicKey, String credentialId) → Future<void>

Operators

operator ==(Object other) → bool
The equality operator.
inherited