WebSocketService class

Constructors

WebSocketService({required bool closeImmediatelyOnResult})

Properties

closeImmediatelyOnResult → bool
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
socket ↔ Socket?
getter/setter pair

Methods

dispose() → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
tryConnect(DataPayload dataPayload) → Future<bool>

Operators

operator ==(Object other) → bool
The equality operator.
inherited