Events enum
Values
- isEventSupported → const Events
- success → const Events
- failure → const Events
- checkBiometric → const Events
- registerBiometric → const Events
- verifyBiometric → const Events
- registerFido → const Events
- signFido → const Events
- getFcmToken → const Events
- isJsFidoSupported → const Events
- registerSilentBinding → const Events
- verifySilentBinding → const Events
- readDeviceDetails → const Events
- copyToClipboard → const Events
- registerIproov → const Events
- verifyIproov → const Events
- getCurrentNetwork → const Events
- loadSekuraSessionUrl → const Events
- isCustomSchemeRegisteredOnApp → const Events
- loadUrl → const Events
- registerEztoPass → const Events
- createSdm → const Events
- getSdmNdef → const Events
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited