contextMenu property
ContextMenu?
get
contextMenu
inherited
Context menu which contains custom menu items to be shown when ContextMenu is presented.
Officially Supported Platforms/Implementations:
- Android WebView
- iOS WKWebView
Use the PlatformInAppBrowser.isPropertySupported method to check if this property is supported at runtime.
Implementation
ContextMenu? get contextMenu => platform.contextMenu;