onAjaxReadyStateChange method
Event fired whenever the readyState attribute of an XMLHttpRequest changes.
It gives the host application a chance to abort the request.
This event is implemented using JavaScript under the hood.
Due to the async nature of this event implementation,
using it could cause some issues, so, be careful when using it.
In this case, you should implement your own logic using for example an UserScript overriding the
XMLHttpRequest JavaScript object.
ajaxRequest represents the XMLHttpRequest.
Officially Supported Platforms/Implementations:
- Android WebView:
- In order to be able to listen this event, check the
InAppWebViewSettings.useShouldInterceptAjaxRequestandInAppWebViewSettings.useOnAjaxReadyStateChangesettings documentation. Also, on Android that doesn't support theWebViewFeature.DOCUMENT_START_SCRIPT, unlike iOS that has WKUserScript that can inject javascript code right after the document element is created but before any other content is loaded, in Android the javascript code used to intercept ajax requests is loaded as soon as possible so it won't be instantaneous as iOS. In that case, after thewindow.addEventListener("flutterInAppWebViewPlatformReady")event is dispatched, the ajax requests can be intercept for sure.
- In order to be able to listen this event, check the
- iOS WKWebView
- macOS WKWebView
Parameters - Officially Supported Platforms/Implementations:
ajaxRequest: all platforms
Use the PlatformInAppBrowserEvents.isMethodSupported method to check if this method is supported at runtime.
Implementation
@override
FutureOr<AjaxRequestAction?>? onAjaxReadyStateChange(
AjaxRequest ajaxRequest,
) {
return null;
}