onContentSizeChanged method
Event fired when the content size of the WebView changes.
oldContentSize represents the old content size value.
newContentSize represents the new content size value.
Officially Supported Platforms/Implementations:
- iOS WKWebView
Parameters - Officially Supported Platforms/Implementations:
oldContentSize: all platformsnewContentSize: all platforms
Use the PlatformInAppBrowserEvents.isMethodSupported method to check if this method is supported at runtime.
Implementation
@override
void onContentSizeChanged(Size oldContentSize, Size newContentSize) {}