onEnterFullscreen method
Event fired when the current page has entered full screen mode.
Officially Supported Platforms/Implementations:
- Android WebView (Official API - WebChromeClient.onShowCustomView)
- iOS WKWebView (Official API - UIWindow.didBecomeVisibleNotification)
- macOS WKWebView (Official API - NSWindow.didEnterFullScreenNotification)
- Windows WebView2 (Official API - ICoreWebView2.add_ContainsFullScreenElementChanged)
Use the PlatformInAppBrowserEvents.isMethodSupported method to check if this method is supported at runtime.
Implementation
@override
void onEnterFullscreen() {}