onExitFullscreen method
Event fired when the current page has exited full screen mode.
Officially Supported Platforms/Implementations:
- Android WebView (Official API - WebChromeClient.onHideCustomView)
- iOS WKWebView (Official API - UIWindow.didBecomeHiddenNotification)
- macOS WKWebView (Official API - NSWindow.didExitFullScreenNotification)
- Windows WebView2 (Official API - ICoreWebView2.add_ContainsFullScreenElementChanged)
Use the PlatformInAppBrowserEvents.isMethodSupported method to check if this method is supported at runtime.
Implementation
@override
void onExitFullscreen() {}