onFormResubmission method
As the host application if the browser should resend data as the requested page was a result of a POST. The default is to not resend the data.
Officially Supported Platforms/Implementations:
- Android WebView (Official API - WebViewClient.onFormResubmission)
Parameters - Officially Supported Platforms/Implementations:
url: all platforms
Use the PlatformInAppBrowserEvents.isMethodSupported method to check if this method is supported at runtime.
Implementation
@override
FutureOr<FormResubmissionAction?>? onFormResubmission(WebUri? url) {
return null;
}