onJsConfirm method
Event fired when javascript calls the confirm() method to display a confirm dialog.
If JsConfirmResponse.handledByClient is true, the webview will assume that the client will handle the dialog.
jsConfirmRequest contains the message to be displayed in the confirm dialog and the of the page requesting the dialog.
Officially Supported Platforms/Implementations:
- Android WebView (Official API - WebChromeClient.onJsConfirm)
- iOS WKWebView (Official API - WKUIDelegate.webView)
- macOS WKWebView (Official API - WKUIDelegate.webView)
Parameters - Officially Supported Platforms/Implementations:
jsConfirmRequest: all platforms
Use the PlatformInAppBrowserEvents.isMethodSupported method to check if this method is supported at runtime.
Implementation
@override
FutureOr<JsConfirmResponse?>? onJsConfirm(JsConfirmRequest jsConfirmRequest) {
return null;
}