onLoadResource method
Event fired when the WebView loads a resource.
NOTE: In order to be able to listen this event, check the InAppWebViewSettings.useOnLoadResource setting documentation.
Officially Supported Platforms/Implementations:
- Android WebView:
- This event is implemented using JavaScript.
- iOS WKWebView:
- This event is implemented using JavaScript.
- macOS WKWebView:
- This event is implemented using JavaScript.
Parameters - Officially Supported Platforms/Implementations:
resource: all platforms
Use the PlatformInAppBrowserEvents.isMethodSupported method to check if this method is supported at runtime.
Implementation
@override
void onLoadResource(LoadedResource resource) {}