onLoadResourceWithCustomScheme method
FutureOr<CustomSchemeResponse?> ?
onLoadResourceWithCustomScheme(
- WebResourceRequest request
inherited
Event fired when the WebView finds the custom-scheme while loading a resource.
Here you can handle the url request and return a CustomSchemeResponse to load a specific resource encoded to base64.
Officially Supported Platforms/Implementations:
- Android WebView
- iOS WKWebView (Official API - WKURLSchemeHandler)
- macOS WKWebView (Official API - WKURLSchemeHandler)
- Windows WebView2
Parameters - Officially Supported Platforms/Implementations:
request: all platforms
Use the PlatformInAppBrowserEvents.isMethodSupported method to check if this method is supported at runtime.
Implementation
@override
FutureOr<CustomSchemeResponse?>? onLoadResourceWithCustomScheme(
WebResourceRequest request,
) {
return null;
}