onMicrophoneCaptureStateChanged method
void
onMicrophoneCaptureStateChanged(
- MediaCaptureState? oldState,
- MediaCaptureState? newState
inherited
Event fired when a change in the microphone capture state occurred.
Officially Supported Platforms/Implementations:
- iOS WKWebView 15.0+
- macOS WKWebView 12.0+
Parameters - Officially Supported Platforms/Implementations:
oldState: all platformsnewState: all platforms
Use the PlatformInAppBrowserEvents.isMethodSupported method to check if this method is supported at runtime.
Implementation
@override
void onMicrophoneCaptureStateChanged(
MediaCaptureState? oldState,
MediaCaptureState? newState,
) {}