onPermissionRequestCanceled method
Notify the host application that the given permission request has been canceled. Any related UI should therefore be hidden.
permissionRequest represents the permission request that needs be canceled
with an array of resources the web content wants to access
and the origin of the web page which is trying to access the restricted resources.
Officially Supported Platforms/Implementations:
- Android WebView 21+ (Official API - WebChromeClient.onPermissionRequestCanceled)
Parameters - Officially Supported Platforms/Implementations:
permissionRequest: all platforms
Use the PlatformInAppBrowserEvents.isMethodSupported method to check if this method is supported at runtime.
Implementation
@override
void onPermissionRequestCanceled(PermissionRequest permissionRequest) {}