onProgressChanged method
Event fired when the current progress of loading a page is changed.
Officially Supported Platforms/Implementations:
- Android WebView (Official API - WebChromeClient.onProgressChanged)
- iOS WKWebView
- macOS WKWebView
- Windows WebView2
Parameters - Officially Supported Platforms/Implementations:
progress: all platforms
Use the PlatformInAppBrowserEvents.isMethodSupported method to check if this method is supported at runtime.
Implementation
@override
void onProgressChanged(progress) {
if (progress == 100) {
pullToRefreshController?.endRefreshing();
}
}