onScrollChanged method
Event fired when the WebView scrolls.
x represents the current horizontal scroll origin in pixels.
y represents the current vertical scroll origin in pixels.
Officially Supported Platforms/Implementations:
- Android WebView (Official API - WebView.onScrollChanged)
- iOS WKWebView (Official API - UIScrollViewDelegate.scrollViewDidScroll)
- macOS WKWebView:
- This event is implemented using JavaScript.
Parameters - Officially Supported Platforms/Implementations:
x: all platformsy: all platforms
Use the PlatformInAppBrowserEvents.isMethodSupported method to check if this method is supported at runtime.
Implementation
@override
void onScrollChanged(int x, int y) {}