onZoomScaleChanged method
Event fired when the zoom scale of the WebView has changed.
oldScale The old zoom scale factor.
newScale The new zoom scale factor.
Officially Supported Platforms/Implementations:
- Android WebView (Official API - WebViewClient.onScaleChanged)
- iOS WKWebView (Official API - UIScrollViewDelegate.scrollViewDidZoom)
- Windows WebView2 (Official API - ICoreWebView2Controller.add_ZoomFactorChanged)
Parameters - Officially Supported Platforms/Implementations:
oldScale: all platformsnewScale: all platforms
Use the PlatformInAppBrowserEvents.isMethodSupported method to check if this method is supported at runtime.
Implementation
@override
void onZoomScaleChanged(double oldScale, double newScale) {}