setSettings method
Sets the PlatformInAppBrowser settings with the new settings and evaluates them.
Officially Supported Platforms/Implementations:
- Android WebView
- iOS WKWebView
- macOS WKWebView
- Windows WebView2
- Linux WPE WebKit
Parameters - Officially Supported Platforms/Implementations:
settings: all platforms
Use the PlatformInAppBrowser.isMethodSupported method to check if this method is supported at runtime.
Implementation
Future<void> setSettings({required InAppBrowserClassSettings settings}) =>
platform.setSettings(settings: settings);