shouldAllowDeprecatedTLS method
FutureOr<ShouldAllowDeprecatedTLSAction?> ?
shouldAllowDeprecatedTLS(
- URLAuthenticationChallenge challenge
inherited
Called when a web view asks whether to continue with a connection that uses a deprecated version of TLS (v1.0 and v1.1).
challenge represents the authentication challenge.
Officially Supported Platforms/Implementations:
- iOS WKWebView 14.0+ (Official API - WKNavigationDelegate.webView)
- macOS WKWebView 11.0+ (Official API - WKNavigationDelegate.webView)
Parameters - Officially Supported Platforms/Implementations:
challenge: all platforms
Use the PlatformInAppBrowserEvents.isMethodSupported method to check if this method is supported at runtime.
Implementation
@override
FutureOr<ShouldAllowDeprecatedTLSAction?>? shouldAllowDeprecatedTLS(
URLAuthenticationChallenge challenge,
) {
return null;
}