shouldInterceptFetchRequest method
Event fired when a request is sent to a server through Fetch API. It gives the host application a chance to take control over the request before sending it. This event is implemented using JavaScript under the hood.
fetchRequest represents a resource request.
Officially Supported Platforms/Implementations:
- Android WebView:
- In order to be able to listen this event, check the
InAppWebViewSettings.useShouldInterceptFetchRequestsetting documentation. Also, on Android that doesn't support theWebViewFeature.DOCUMENT_START_SCRIPT, unlike iOS that has WKUserScript that can inject javascript code right after the document element is created but before any other content is loaded, in Android the javascript code used to intercept ajax requests is loaded as soon as possible so it won't be instantaneous as iOS. In that case, after thewindow.addEventListener("flutterInAppWebViewPlatformReady")event is dispatched, the ajax requests can be intercept for sure.
- In order to be able to listen this event, check the
- iOS WKWebView
- macOS WKWebView
Parameters - Officially Supported Platforms/Implementations:
fetchRequest: all platforms
Use the PlatformInAppBrowserEvents.isMethodSupported method to check if this method is supported at runtime.
Implementation
@override
FutureOr<FetchRequest?>? shouldInterceptFetchRequest(
FetchRequest fetchRequest,
) {
return null;
}